@@ -67,9 +67,8 @@ class Link(object):
 
         implemented through numerical differentiation
         """
-        from statsmodels.tools.numdiff import approx_fprime_cs
-        # TODO: workaround proplem with numdiff for 1d
-        return np.diag(approx_fprime_cs(p, self.deriv))
+        from statsmodels.tools.numdiff import _approx_fprime_cs_scalar
+        return _approx_fprime_cs_scalar(p, self.deriv)
 
     def inverse_deriv(self, z):
         """
@@ -676,14 +675,24 @@ class CDFLink(Logit):
 
         implemented through numerical differentiation
         """
-        from statsmodels.tools.numdiff import approx_fprime
+        p = self._clean(p)
+        linpred = self.dbn.ppf(p)
+        return - self.inverse_deriv2(linpred) / self.dbn.pdf(linpred)**3
+
+    def deriv2_numdiff(self, p):
+        """
+        Second derivative of the link function g''(p)
+
+        implemented through numerical differentiation
+        """
+        from statsmodels.tools.numdiff import _approx_fprime_scalar
         p = np.atleast_1d(p)
         # Note: special function for norm.ppf does not support complex
-        return np.diag(approx_fprime(p, self.deriv, centered=True))
+        return _approx_fprime_scalar(p, self.deriv, centered=True)
 
     def inverse_deriv(self, z):
         """
-        Derivative of the inverse of the CDF transformation link function
+        Derivative of the inverse link function
 
         Parameters
         ----------
@@ -693,9 +702,37 @@ class CDFLink(Logit):
         Returns
         -------
         g^(-1)'(z) : ndarray
-            The value of the derivative of the inverse of the logit function
+            The value of the derivative of the inverse of the logit function.
+            This is just the pdf in a CDFLink,
         """
-        return 1/self.deriv(self.inverse(z))
+        return self.dbn.pdf(z)
+
+    def inverse_deriv2(self, z):
+        """
+        Second derivative of the inverse link function g^(-1)(z).
+
+        Parameters
+        ----------
+        z : array_like
+            `z` is usually the linear predictor for a GLM or GEE model.
+
+        Returns
+        -------
+        g^(-1)''(z) : ndarray
+            The value of the second derivative of the inverse of the link
+            function
+
+        Notes
+        -----
+        This method should be overwritten by subclasses.
+
+        The inherited method is implemented through numerical differentiation.
+        """
+        from statsmodels.tools.numdiff import _approx_fprime_scalar
+        z = np.atleast_1d(z)
+
+        # Note: special function for norm.ppf does not support complex
+        return _approx_fprime_scalar(z, self.inverse_deriv, centered=True)
 
 
 class probit(CDFLink):
@@ -708,7 +745,24 @@ class probit(CDFLink):
 
     probit is an alias of CDFLink.
     """
-    pass
+
+    def inverse_deriv2(self, z):
+        """
+        Second derivative of the inverse link function
+
+        This is the derivative of the pdf in a CDFLink
+
+        """
+        return - z * self.dbn.pdf(z)
+
+    def deriv2(self, p):
+        """
+        Second derivative of the link function g''(p)
+
+        """
+        p = self._clean(p)
+        linpred = self.dbn.ppf(p)
+        return linpred / self.dbn.pdf(linpred)**2
 
 
 class cauchy(CDFLink):
@@ -739,10 +793,15 @@ class cauchy(CDFLink):
         g''(p) : ndarray
             Value of the second derivative of Cauchy link function at `p`
         """
+        p = self._clean(p)
         a = np.pi * (p - 0.5)
         d2 = 2 * np.pi**2 * np.sin(a) / np.cos(a)**3
         return d2
 
+    def inverse_deriv2(self, z):
+
+        return - 2 * z / (np.pi * (z**2 + 1)**2)
+
 
 class CLogLog(Logit):
     """
@@ -869,6 +928,141 @@ class cloglog(CLogLog):
     pass
 
 
+class LogLog(Logit):
+    """
+    The log-log transform
+
+    LogLog inherits from Logit in order to have access to its _clean method
+    for the link and its derivative.
+    """
+    def __call__(self, p):
+        """
+        Log-Log transform link function
+
+        Parameters
+        ----------
+        p : ndarray
+            Mean parameters
+
+        Returns
+        -------
+        z : ndarray
+            The LogLog transform of `p`
+
+        Notes
+        -----
+        g(p) = -log(-log(p))
+        """
+        p = self._clean(p)
+        return -np.log(-np.log(p))
+
+    def inverse(self, z):
+        """
+        Inverse of Log-Log transform link function
+
+
+        Parameters
+        ----------
+        z : array_like
+            The value of the inverse of the LogLog link function at `p`
+
+        Returns
+        -------
+        p : ndarray
+            Mean parameters
+
+        Notes
+        -----
+        g^(-1)(`z`) = exp(-exp(`z`))
+        """
+        return np.exp(-np.exp(-z))
+
+    def deriv(self, p):
+        """
+        Derivative of Log-Log transform link function
+
+        Parameters
+        ----------
+        p : array_like
+            Mean parameters
+
+        Returns
+        -------
+        g'(p) : ndarray
+            The derivative of the LogLog transform link function
+
+        Notes
+        -----
+        g'(p) = - 1 /p * log(p)
+        """
+        p = self._clean(p)
+        return -1. / (p * (np.log(p)))
+
+    def deriv2(self, p):
+        """
+        Second derivative of the Log-Log link function
+
+        Parameters
+        ----------
+        p : array_like
+            Mean parameters
+
+        Returns
+        -------
+        g''(p) : ndarray
+            The second derivative of the LogLog link function
+        """
+        p = self._clean(p)
+        d2 = (1 + np.log(p)) / (p * (np.log(p)))**2
+        return d2
+
+    def inverse_deriv(self, z):
+        """
+        Derivative of the inverse of the Log-Log transform link function
+
+        Parameters
+        ----------
+        z : array_like
+            The value of the inverse of the LogLog link function at `p`
+
+        Returns
+        -------
+        g^(-1)'(z) : ndarray
+            The derivative of the inverse of the LogLog link function
+        """
+        return np.exp(-np.exp(-z) - z)
+
+    def inverse_deriv2(self, z):
+        """
+        Second derivative of the inverse of the Log-Log transform link function
+
+        Parameters
+        ----------
+        z : array_like
+            The value of the inverse of the LogLog link function at `p`
+
+        Returns
+        -------
+        g^(-1)''(z) : ndarray
+            The second derivative of the inverse of the LogLog link function
+        """
+        return self.inverse_deriv(z) * (np.exp(-z) - 1)
+
+
+class loglog(LogLog):
+    """
+    The LogLog transform link function.
+
+    Notes
+    -----
+    g(`p`) = -log(-log(`p`))
+
+    loglog is an alias for LogLog
+    loglog = LogLog()
+    """
+    pass
+
+
 class NegativeBinomial(Link):
     '''
     The negative binomial link function
