@@ -29,12 +29,12 @@ class R_Results(object):
 
     Parameters
     ----------
-    meth : string
+    meth : str
         Either "ml" or "reml".
-    irfs : string
+    irfs : str
         Either "irf", for independent random effects, or "drf" for
         dependent random effects.
-    ds_ix : integer
+    ds_ix : int
         The number of the data set
     """
 
@@ -122,13 +122,14 @@ class TestMixedLM(object):
             vc["a"][i] = exog_vc[ix, 0:2]
             vc["b"][i] = exog_vc[ix, 2:3]
 
-        model = MixedLM(
-            endog,
-            exog_fe,
-            groups,
-            exog_re,
-            exog_vc=vc,
-            use_sqrt=use_sqrt)
+        with pytest.warns(UserWarning, match="Using deprecated variance"):
+            model = MixedLM(
+                endog,
+                exog_fe,
+                groups,
+                exog_re,
+                exog_vc=vc,
+                use_sqrt=use_sqrt)
         rslt = model.fit(reml=reml)
 
         loglike = loglike_function(
@@ -151,12 +152,15 @@ class TestMixedLM(object):
                 ngr = nd.approx_fprime(params_vec, loglike)
                 assert_allclose(gr, ngr, rtol=1e-3)
 
-            # Check Hessian matrices at the MLE (we don't have
-            # the profile Hessian matrix and we don't care
+            # Check Hessian matrices at the MLE (we do not have
+            # the profile Hessian matrix and we do not care
             # about the Hessian for the square root
             # transformed parameter).
             if (profile_fe is False) and (use_sqrt is False):
-                hess = -model.hessian(rslt.params_object)
+                hess, sing = model.hessian(rslt.params_object)
+                if sing:
+                    pytest.fail("hessian should not be singular")
+                hess *= -1
                 params_vec = rslt.params_object.get_packed(
                     use_sqrt=False, has_fe=True)
                 loglike_h = loglike_function(
@@ -221,17 +225,13 @@ class TestMixedLM(object):
             ii = np.flatnonzero(groups == k)
             vc["a"][k] = vca[ii][:, None]
             vc["b"][k] = vcb[ii][:, None]
-        rslt = MixedLM(
-            endog, exog, groups=groups, exog_re=exog_re, exog_vc=vc).fit()
-        rslt.profile_re(
-            0, vtype='re', dist_low=1, num_low=3, dist_high=1, num_high=3)
-        rslt.profile_re(
-            'b',
-            vtype='vc',
-            dist_low=0.5,
-            num_low=3,
-            dist_high=0.5,
-            num_high=3)
+        with pytest.warns(UserWarning, match="Using deprecated variance"):
+            rslt = MixedLM(endog, exog, groups=groups,
+                           exog_re=exog_re, exog_vc=vc).fit()
+        rslt.profile_re(0, vtype='re', dist_low=1, num_low=3,
+                        dist_high=1, num_high=3)
+        rslt.profile_re('b', vtype='vc', dist_low=0.5, num_low=3,
+                        dist_high=0.5, num_high=3)
 
     def test_vcomp_1(self):
         # Fit the same model using constrained random effects and
@@ -260,7 +260,8 @@ class TestMixedLM(object):
             ix = model1.row_indices[group]
             exog_vc["a"][group] = exog_re[ix, 0:1]
             exog_vc["b"][group] = exog_re[ix, 1:2]
-        model2 = MixedLM(endog, exog, groups, exog_vc=exog_vc)
+        with pytest.warns(UserWarning, match="Using deprecated variance"):
+            model2 = MixedLM(endog, exog, groups, exog_vc=exog_vc)
         result2 = model2.fit()
         result2.summary()
 
@@ -471,7 +472,7 @@ class TestMixedLM(object):
         data = pd.read_csv(fname)
         model = MixedLM.from_formula(
             "Weight ~ Time", groups="Pig", re_formula="1 + Time", data=data)
-        result = model.fit(method='powell')
+        result = model.fit(method="cg")
 
         # fixef(r)
         assert_allclose(
@@ -498,7 +499,7 @@ class TestMixedLM(object):
         data = pd.read_csv(fname)
         model = MixedLM.from_formula(
             "Weight ~ Time", groups="Pig", re_formula="1 + Time", data=data)
-        result = model.fit(method='powell', reml=False)
+        result = model.fit(method='cg', reml=False)
 
         # fixef(r)
         assert_allclose(result.fe_params, np.r_[15.73863, 6.93902], rtol=1e-5)
@@ -559,7 +560,7 @@ class TestMixedLM(object):
         # logLik(r)
         assert_allclose(result.llf, -123.49, rtol=1e-1)
 
-        # don't provide aic/bic with REML
+        # do not provide aic/bic with REML
         assert_equal(result.aic, np.nan)
         assert_equal(result.bic, np.nan)
 
@@ -629,7 +630,9 @@ class TestMixedLM(object):
             ix = np.flatnonzero(groups == group)
             exog_vc["a"][group] = ex_vc[ix, 0:2]
             exog_vc["b"][group] = ex_vc[ix, 2:]
-        model1 = MixedLM(endog, exog, groups, exog_re=exog_re, exog_vc=exog_vc)
+        with pytest.warns(UserWarning, match="Using deprecated variance"):
+            model1 = MixedLM(endog, exog, groups, exog_re=exog_re,
+                             exog_vc=exog_vc)
         result1 = model1.fit()
 
         df = pd.DataFrame(exog[:, 1:], columns=["x1"])
@@ -1089,14 +1092,14 @@ def test_random_effects_getters():
         b.append(bb)
 
         # First variance component
-        vv0 = np.kron(np.r_[0, 1], np.ones(m // 2)).astype(np.int)
+        vv0 = np.kron(np.r_[0, 1], np.ones(m // 2)).astype(int)
         cc0 = np.random.normal(size=2)
         yy += cc0[vv0]
         v0.append(vv0)
         c0.append(cc0)
 
         # Second variance component
-        vv1 = np.kron(np.ones(m // 2), np.r_[0, 1]).astype(np.int)
+        vv1 = np.kron(np.ones(m // 2), np.r_[0, 1]).astype(int)
         cc1 = np.random.normal(size=2)
         yy += cc1[vv1]
         v1.append(vv1)
@@ -1235,6 +1238,24 @@ class TestSMWLogdet(object):
         check_smw_logdet(p, q, r, s)
 
 
+def test_singular():
+    # Issue #7051
+
+    np.random.seed(3423)
+    n = 100
+
+    data = np.random.randn(n, 2)
+    df = pd.DataFrame(data, columns=['Y', 'X'])
+    df['class'] = pd.Series([i % 3 for i in df.index], index=df.index)
+
+    with pytest.warns(Warning) as wrn:
+        md = MixedLM.from_formula("Y ~ X", df, groups=df['class'])
+        mdf = md.fit()
+        mdf.summary()
+        if not wrn:
+            pytest.fail("warning expected")
+
+
 def test_get_distribution():
 
     np.random.seed(234)
@@ -1251,7 +1272,7 @@ def test_get_distribution():
     exog_vca = np.random.normal(size=(n, 2))
     exog_vcb = np.random.normal(size=(n, 2))
 
-    groups = np.repeat(np.arange(n_groups, dtype=np.int),
+    groups = np.repeat(np.arange(n_groups, dtype=int),
                        n / n_groups)
 
     ey = np.dot(exog_fe, fe_params)
